// --- [ rtc.h ] --------------------------------------------------------------

void rtc_init(void);

void rtc_setTime(uint8_t * time);
void rtc_getTime(uint8_t * time);

void rtc_setAlarm_A(uint8_t * time);
void rtc_setAlarm_B(uint8_t * time);

uint8_t rtc_getAlarmFlags(void);

void rtc_clrAlarm_A(void);
void rtc_clrAlarm_B(void);

void rtc_setPeriodicIRQ(uint8_t i);
void rtc_clrPeriodicIRQ(void);

void rtc_printRegisters(void);

// die Wochentag der Uhr/Zeitzhlung - von 0 bis 6
#define SONNTAG 		0
#define MONTAG  		1
#define DIENSTAG 		2
#define MITTWOCH 		3
#define DONNERSTAG 	4
#define FREITAG 		5
#define SAMSTAG 		6

// die Wochentage fr die Alarmmaske, 0 = kein Alarm !
// die Maske entsteht durch Addition der Tage mit Alarmauslsung
#define SO			1
#define MO  		2
#define II			4
#define MI			8
#define DO			16
#define FR			32
#define SA			64
#define ALL			0x7F

#define SEKUNDE	0
#define MINUTE		1
#define STUNDE		2
#define DOW			4
#define TAG			5
#define MONAAT		6
#define JAHR		7

// Bits in Register Ctrl_Reg 1
#define CT0			0
#define CT1			1
#define CT2			2

// Periodic Interrupt
#define P_IRQ_OFF			(0<<CT2 | 0<<CT1 | 0<<CT0)		// abgeschaltet: Level high
#define P_IRQ_OFF_LOW	(0<<CT2 | 0<<CT1 | 1<<CT0)		// abgeschaltet: Level low
#define P_IRQ_2HZ			(0<<CT2 | 1<<CT1 | 0<<CT0)
#define P_IRQ_1HZ			(0<<CT2 | 1<<CT1 | 1<<CT0)
#define P_IRQ_SEKUNDE	(1<<CT2 | 0<<CT1 | 0<<CT0)
#define P_IRQ_MINUTE		(1<<CT2 | 0<<CT1 | 1<<CT0)
#define P_IRQ_STUNDE		(1<<CT2 | 1<<CT1 | 0<<CT0)
#define P_IRQ_MONAT		(1<<CT2 | 1<<CT1 | 1<<CT0)


// --- [ eof ] -----------------------------------------------------------------
